@@ -1,8 +1,7 @@
-#-------------#
 import torch
 import torch.nn as nn
 from torch.nn.utils.rnn import pad_sequence
-#-------------#
+
 from .decoar2 import Decoar2
 from .audio import create_transform
 from collections import OrderedDict
@@ -24,15 +23,16 @@ class UpstreamExpert(UpstreamBase):
 
     def __init__(self, ckpt, **kwargs):
         super(UpstreamExpert, self).__init__()
-        models = torch.load(ckpt)['model']
+        models = torch.load(ckpt)["model"]
         self.model = Decoar2()
         component_state_dict = OrderedDict()
         for key in models.keys():
             component_state_dict[key] = models[key]
         self.model.load_state_dict(component_state_dict, strict=False)
 
-        self.preprocessor = create_transform()
+        self.model.encoder.layerdrop = 0.0
 
+        self.preprocessor = create_transform()
         self.output_dim = 768
 
         if len(self.hooks) == 0:
@@ -66,9 +66,7 @@ class UpstreamExpert(UpstreamBase):
         size = max(feat_lengths)
         features = pad_sequence(features, batch_first=True)
 
-        padding_mask = (
-            torch.BoolTensor(features.shape).fill_(False).to(features.device)
-        )
+        padding_mask = torch.BoolTensor(features.shape).fill_(False).to(features.device)
 
         for i in range(len(feat_lengths)):
             diff = feat_lengths[i] - size
